#define _MCMCGLMMCC_H

/* #include "cs.h" included by MCMCglmm.h */
#include "MCMCglmm.h" 
//#include <math.h> already included via R.h
#include <map>                  
//#include <stdlib.h> already included via R.h
#include <new>            
/* already included
#include "R.h" 
#include "Rmath.h" 
*/
#include <iostream>
#include <limits>
using namespace std;



